UpdateDataCatalogInputBuilder

Struct UpdateDataCatalogInputBuilder 

#[non_exhaustive]
pub struct UpdateDataCatalogInputBuilder { /* private fields */ }
A builder for UpdateDataCatalogInput.

Implementations

Source

impl UpdateDataCatalogInputBuilder

pub fn name(self, input: impl Into<String>) -> Self

The name of the data catalog to update. The catalog name must be unique for the Amazon Web Services account and can use a maximum of 127 alphanumeric, underscore, at sign, or hyphen characters. The remainder of the length constraint of 256 is reserved for use by Athena.

This field is required.
pub fn set_name(self, input: Option<String>) -> Self

The name of the data catalog to update. The catalog name must be unique for the Amazon Web Services account and can use a maximum of 127 alphanumeric, underscore, at sign, or hyphen characters. The remainder of the length constraint of 256 is reserved for use by Athena.

pub fn get_name(&self) -> &Option<String>

The name of the data catalog to update. The catalog name must be unique for the Amazon Web Services account and can use a maximum of 127 alphanumeric, underscore, at sign, or hyphen characters. The remainder of the length constraint of 256 is reserved for use by Athena.

pub fn type(self, input: DataCatalogType) -> Self

Specifies the type of data catalog to update. Specify LAMBDA for a federated catalog, HIVE for an external hive metastore, or GLUE for an Glue Data Catalog.

This field is required.
pub fn set_type(self, input: Option<DataCatalogType>) -> Self

Specifies the type of data catalog to update. Specify LAMBDA for a federated catalog, HIVE for an external hive metastore, or GLUE for an Glue Data Catalog.

pub fn get_type(&self) -> &Option<DataCatalogType>

Specifies the type of data catalog to update. Specify LAMBDA for a federated catalog, HIVE for an external hive metastore, or GLUE for an Glue Data Catalog.

pub fn description(self, input: impl Into<String>) -> Self

New or modified text that describes the data catalog.

pub fn set_description(self, input: Option<String>) -> Self

New or modified text that describes the data catalog.

pub fn get_description(&self) -> &Option<String>

New or modified text that describes the data catalog.

pub fn parameters(self, k: impl Into<String>, v: impl Into<String>) -> Self

Adds a key-value pair to parameters.

To override the contents of this collection use set_parameters.

Specifies the Lambda function or functions to use for updating the data catalog. This is a mapping whose values depend on the catalog type.

  • For the HIVE data catalog type, use the following syntax. The metadata-function parameter is required. The sdk-version parameter is optional and defaults to the currently supported version.

    metadata-function=lambda_arn, sdk-version=version_number

  • For the LAMBDA data catalog type, use one of the following sets of required parameters, but not both.

    • If you have one Lambda function that processes metadata and another for reading the actual data, use the following syntax. Both parameters are required.

      metadata-function=lambda_arn, record-function=lambda_arn

    • If you have a composite Lambda function that processes both metadata and data, use the following syntax to specify your Lambda function.

      function=lambda_arn

pub fn set_parameters(self, input: Option<HashMap<String, String>>) -> Self

Specifies the Lambda function or functions to use for updating the data catalog. This is a mapping whose values depend on the catalog type.

  • For the HIVE data catalog type, use the following syntax. The metadata-function parameter is required. The sdk-version parameter is optional and defaults to the currently supported version.

    metadata-function=lambda_arn, sdk-version=version_number

  • For the LAMBDA data catalog type, use one of the following sets of required parameters, but not both.

    • If you have one Lambda function that processes metadata and another for reading the actual data, use the following syntax. Both parameters are required.

      metadata-function=lambda_arn, record-function=lambda_arn

    • If you have a composite Lambda function that processes both metadata and data, use the following syntax to specify your Lambda function.

      function=lambda_arn

pub fn get_parameters(&self) -> &Option<HashMap<String, String>>

Specifies the Lambda function or functions to use for updating the data catalog. This is a mapping whose values depend on the catalog type.

  • For the HIVE data catalog type, use the following syntax. The metadata-function parameter is required. The sdk-version parameter is optional and defaults to the currently supported version.

    metadata-function=lambda_arn, sdk-version=version_number

  • For the LAMBDA data catalog type, use one of the following sets of required parameters, but not both.

    • If you have one Lambda function that processes metadata and another for reading the actual data, use the following syntax. Both parameters are required.

      metadata-function=lambda_arn, record-function=lambda_arn

    • If you have a composite Lambda function that processes both metadata and data, use the following syntax to specify your Lambda function.

      function=lambda_arn

pub fn build(self) -> Result<UpdateDataCatalogInput, BuildError>

Consumes the builder and constructs a UpdateDataCatalogInput.

Source

impl UpdateDataCatalogInputBuilder

pub async fn send_with( self, client: &Client, ) -> Result<UpdateDataCatalogOutput, SdkError<UpdateDataCatalogError, HttpResponse>>

Sends a request with this input using the given client.